#
# spec file for package multipath-tools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Workaround for Leap 42.1 bug, bsc#940315
%if 0%{?suse_version} == 1315
%if 0%{?is_opensuse} == 1
%if 0%{?sle_version} == 0
%define sle_version 120100
%endif
%endif
%endif

# Whether to build with RADOS support
# Default YES on openSUSE factory and leap >= 42.2 and SLES12 >= SP3
# (but only on architectures for which ceph is enabled).
# Default NO on SLES 12 >= SP2
# Always NO on other distros

%if 0%{?suse_version} == 1315
%if 0%{?is_opensuse} == 1
#### Leap 42.x: Support from 42.2 on, for ceph-supported archs
#### (see ExclusiveArch in ceph spec file)
%ifarch x86_64 aarch64 ppc64 ppc64le
%if 0%{?sle_version} >= 120200
%bcond_without rados
%endif # 0%{?sle_version} >= 120200
%endif # arch
%else  # 0%{?is_opensuse} == 1
#### SLE12: Support from SP3 on, for ceph-supported archs
#### (see ExclusiveArch in ceph spec file *on IBS*)
%ifarch x86_64 aarch64
%if 0%{?sle_version} >= 120300
%bcond_without rados
%else  # 0%{?sle_version} >= 120300
#### SLE12 SP2: rados can be enabled here using --with rados
%if 0%{?sle_version} >= 120200
%bcond_with rados
%endif # 0%{?sle_version} >= 120200
%endif # 0%{?sle_version} >= 120300
%endif # arch
%endif # 0%{?is_opensuse} == 1
%else  # 0%{?suse_version} == 1315
%if 0%{?suse_version} >= 1330
%if 0%{?is_opensuse} == 1
#### Factory / Tumbleweed
#### (see ExclusiveArch in ceph spec file)
%ifarch x86_64 aarch64 ppc64 ppc64le
%bcond_without rados
%endif # arch
%else  # 0%{?is_opensuse} == 1
#### SLE15
#### (see ExclusiveArch in ceph spec file)
%ifarch x86_64 aarch64 ppc64le s390x
%bcond_without rados
%endif # arch
%endif # 0%{?is_opensuse} == 1
%endif # 0%{?suse_version} >= 1330
%endif # 0%{?suse_version} == 1315

# Whether to build libdmmp
# Default YES on openSUSE factory, SLE15, and leap
# Default NO on SLES 12
# Always NO on other distros
%if 0%{?suse_version} == 1315
%if 0%{?is_opensuse} == 1
%bcond_without libdmmp
%else  # 0%{?is_opensuse} == 1
%bcond_with libdmmp
%endif # 0%{?is_opensuse} == 1
%else  # 0%{?is_opensuse} == 1
%if 0%{?suse_version} >= 1330
%bcond_without libdmmp
%endif # 0%{?suse_version} >= 1330
%endif # 0%{?suse_version} == 1315

# This should match the version in libdmmp/Makefile
%define _libdmmp_version 0.1.0
%define libdmmp_version %(echo %{_libdmmp_version} | tr . _)

# path prefix for systemd unit files and udev rules
%define _sysdir usr/lib

Name:           multipath-tools
Url:            http://christophe.varoqui.free.fr/
Version:        0.7.3+173+suse.7dd1b01
Release:        150000.3.29.1
Summary:        Tools to Manage Multipathed Devices with the device-mapper
License:        GPL-2.0-only AND LGPL-2.0-or-later
Group:          System/Base
Source:         multipath-tools-%{version}.tar.xz
Source1:        multipath.conf
# SUSE policy: disable partition deletion by default
Source2:        dont-del-part-nodes.rules
# Dracut conf file to make sure 11-dm-parts.rules is included in initrd
Source3:        dm-parts.conf
Source4:        libmpathpersist-example.c
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
BuildRequires:  device-mapper-devel
BuildRequires:  libaio-devel
%if 0%{?with_rados} == 1
BuildRequires:  librados-devel
%endif
%if 0%{?with_libdmmp} == 1
BuildRequires:  libjson-c-devel
%endif
BuildRequires:  libudev-devel
BuildRequires:  liburcu-devel
BuildRequires:  udev
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
# dracut owns dracut.conf.d
BuildRequires:  dracut
Requires:       device-mapper >= 1.2.78
Requires:       kpartx
Requires:       sg3_utils
Recommends:     multipath-tools-rbd = %{version}
PreReq:         coreutils grep

%description
This package provides the tools to manage multipathed devices by
instructing the device-mapper multipath module what to do. The tools
are:

- multipath: scans the system for multipathed devices, assembles
   them, and updates the device-mapper's maps

- multipathd: waits for maps events then execs multipath

- devmap-name: provides a meaningful device name to udev for devmaps

- kpartx: maps linear devmaps to device partitions, which makes
multipath maps partionable

%package -n kpartx
Summary:        Manages partition tables on device-mapper devices
License:        GPL-2.0-only
Group:          System/Base
Requires:       device-mapper

%description -n kpartx
The kpartx program maps linear devmaps to device partitions, which
makes multipath maps partionable.

%package devel
Summary:        Development libraries for multipath-tools
License:        GPL-2.0-only AND LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       device-mapper
Requires:       multipath-tools = %{version}

%description devel
This package contains the development libraries for multipath-tools
and libmpath_persist.

%if 0%{?with_rados} == 1
%package rbd
Summary:        RADOS support for multipath-tools
License:        LGPL-2.1-only
Group:          System/Libraries
Requires:       multipath-tools = %{version}

%description rbd
This package contains the path checker for RADOS block devices
(provided by the Ceph distributed storage system) for multipath-tools.

%endif

%if 0%{?with_libdmmp} == 1
%package -n libdmmp%{libdmmp_version}
Summary:        C API for multipath-tools
License:        GPL-3.0-or-later
Group:          System/Libraries
Requires:       multipath-tools

%description -n libdmmp%{libdmmp_version}
This library enables the use of libmultipath commands from C code.

%package -n libdmmp-devel
Summary:        Header files for multipath-tools C API
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libdmmp%{libdmmp_version} = %{version}

%description -n libdmmp-devel
This package provides development files and documentation for libdmmp.

%endif

%define makeflags %{!?with_rados:ENABLE_RADOS=0} %{!?with_libdmmp:ENABLE_LIBDMMP=0}
%define dirflags LIB=%{_lib} usr_prefix=%{_prefix} SYSTEMDPATH=%{_sysdir}

%prep
%setup -q -n multipath-tools-%{version}
cp %{SOURCE4} .

%build
[ -n "$SOURCE_DATE_EPOCH" ] && export KBUILD_BUILD_TIMESTAMP=@$SOURCE_DATE_EPOCH
make CC="%__cc" OPTFLAGS="%{optflags}" %{dirflags} %{makeflags}

%install
make DESTDIR=%{buildroot} %{dirflags} %{makeflags} install
mkdir -p %{buildroot}/var/cache/multipath/
mkdir -p %{buildroot}%{_defaultlicensedir}
mkdir -p %{buildroot}/usr/sbin
mkdir -p %{buildroot}/usr/%{_lib}
for x in multipath mpathpersist mpathcmd; do
    rm -f %{buildroot}/%{_lib}/lib$x.so
    ln -sf /%{_lib}/lib$x.so.0  %{buildroot}/usr/%{_lib}/lib$x.so
done
ln -sf /usr/sbin/service %{buildroot}/usr/sbin/rcmultipathd
mkdir -p %{buildroot}/usr/lib/modules-load.d
install -m 644 -D %{SOURCE1} "%{buildroot}/usr/lib/modules-load.d/multipath.conf"
install -m 644 %{SOURCE2} %{buildroot}%{_udevrulesdir}/00-dont-del-part-nodes.rules
install -m 644 -D %{SOURCE3} %{buildroot}/usr/lib/dracut/dracut.conf.d/dm-parts.conf

%pre
[ -f /.buildenv ] && exit 0
if [ -f /etc/init.d/multipathd ] && dmsetup --target multipath table | grep -q multipath ; then
  /etc/init.d/multipathd stop
  %service_add_pre multipathd.socket
  %service_add_pre multipathd.service
fi

%post
[ -f /.buildenv ] && exit 0
%{run_ldconfig}
if dmsetup --target multipath table | grep -q multipath ; then
  %service_add_post multipathd.socket
  %service_add_post multipathd.service
fi
%{?regenerate_initrd_post}
exit 0

%preun
%service_del_preun multipathd.service
%service_del_preun multipathd.socket

%postun
%{?regenerate_initrd_post}
%service_del_postun multipathd.service
%service_del_postun multipathd.socket
%{run_ldconfig}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%defattr(-,root,root)
%doc README
%dir %{_defaultlicensedir}
%license LICENSES/LGPL-2.0
%license LICENSES/LGPL-2.1
%license LICENSES/GPL-2.0
%license README.licenses
%{_udevrulesdir}/11-dm-mpath.rules
%{_udevrulesdir}/56-multipath.rules
/%{_lib}/libmultipath.so.0
/%{_lib}/libmpathcmd.so.0
/%{_lib}/libmpathpersist.so.0
/%{_lib}/multipath
%if 0%{?with_rados} == 1
%exclude /%{_lib}/multipath/libcheckrbd.so
%endif
/sbin/multipath
/sbin/multipathd
/sbin/mpathpersist
/usr/sbin/rcmultipathd
%attr (0700, root, root) /var/cache/multipath
%dir /%{_sysdir}/systemd/system
/%{_sysdir}/systemd/system/multipathd.service
/%{_sysdir}/systemd/system/multipathd.socket
%dir /usr/lib/modules-load.d
/usr/lib/modules-load.d/multipath.conf
%{_mandir}/man8/multipath.8*
%{_mandir}/man5/multipath.conf.5*
%{_mandir}/man8/multipathd.8*
%{_mandir}/man8/mpathpersist.8*

%files devel
%defattr(-,root,root)
/usr/%{_lib}/libmultipath.so
/usr/%{_lib}/libmpathcmd.so
/usr/%{_lib}/libmpathpersist.so
/usr/include/mpath_cmd.h
/usr/include/mpath_persist.h
%{_mandir}/man3/mpath_persistent_*
%doc libmpathpersist-example.c

%files -n kpartx
%defattr(-,root,root)
%license LICENSES/GPL-2.0
/sbin/kpartx
%{_udevrulesdir}/00-dont-del-part-nodes.rules
%{_udevrulesdir}/11-dm-parts.rules
%{_udevrulesdir}/66-kpartx.rules
%{_udevrulesdir}/68-del-part-nodes.rules
/%{_sysdir}/udev/kpartx_id
# SLE12-SP1 and earlier: dracut does not own /usr/lib/dracut/dracut.conf.d
%if 0%{?sle_version}
%if 0%{?sle_version} <= 120100
%dir /%{_sysdir}/dracut/dracut.conf.d
%endif # 0%{?sle_version} <= 120100
%endif # 0%{?sle_version}
/%{_sysdir}/dracut/dracut.conf.d/dm-parts.conf
%{_mandir}/man8/kpartx.8*

%posttrans -n kpartx
# The kpartx package contains udev rules that may need to be in initrd.
%{?regenerate_initrd_posttrans}

%if 0%{?with_rados} == 1
%files rbd
%defattr(-,root,root)
/%{_lib}/multipath/libcheckrbd.so
%endif

%if 0%{?with_libdmmp} == 1

%post -n libdmmp%{libdmmp_version}
%{run_ldconfig}

%postun -n libdmmp%{libdmmp_version}
%{run_ldconfig}

%files -n libdmmp%{libdmmp_version}
%defattr(-,root,root)
%license LICENSES/GPL-3.0
/%{_libdir}/libdmmp.so.%{_libdmmp_version}

%files -n libdmmp-devel
%defattr(-,root,root)
/%{_libdir}/libdmmp.so
%{_mandir}/man3/libdmmp.h*
%{_mandir}/man3/dmmp_*
%{_includedir}/libdmmp
%{_libdir}/pkgconfig/libdmmp.pc

%endif # with_libdmmp

%changelog
* Mon Oct 17 2022 mwilck@suse.com
- Update to version 0.7.3+173+suse.7dd1b01:
  * fix crash in liburcu (bsc#1204325)
* Fri Sep 30 2022 mwilck@suse.com
- Update to version 0.7.3+172+suse.cd6a00a:
  * Fix multipathd authorization bypass (bsc#1202739 CVE-2022-41974)
* Fri Aug 26 2022 mwilck@suse.com
- Update to version 0.7.3+171+suse.4e5467e:
  * Avoid linking to libreadline to avoid licensing issue
    (bsc#1202616)
* Tue Sep 24 2019 mwilck@suse.com
- Update to version 0.7.3+150+suse.529bc38:
  * libmultipath: Fix logic in should_multipath (bsc#1151502)
    (fixed upstream in 0.7.7)
* Fri Sep  6 2019 mwilck@suse.com
- Update to version 0.7.3+149+suse.9242a19:
  * Fix premature path reinstantiation with san_path_err_XX
    (boo#1149319)
  * libmultipath: make lazy tpgs probing work again (bsc#1149313)
* Tue Jul 16 2019 mwilck@suse.com
- Update to version 0.7.3+147+suse.1382aee:
  * Added basic NVMe ANA support (bsc#1119898, bsc#1118495)
* Tue Jun 25 2019 mwilck@suse.com
- Update to version 0.7.3+139+suse.e05ebca:
  * mpathpersist: optimize for setups with many LUNs (bsc#1134648)
  * mpathpersist: add option -f/--batch-file (bsc#1134648)
  * libmultipath: get_prio(): really don't reset prio for
    inaccessible paths (bsc#1118495)
- Upstream bug fixes from dm-devel (bsc#1139369):
  * multipath: call store_pathinfo with DI_BLACKLIST
- hwtable: add Lenovo DE series (bsc#1125507)
* Tue Apr 30 2019 mwilck@suse.com
- Update to version 0.7.3+126+suse.0aeeee7:
  * Fix priority handling for offline paths
  (bsc#1118495)
  * Avoid device IO in "multipath -u" (bsc#1125145)
  * Avoid deadlock situation during udev settle
  (bsc#1131789, bsc#1125145)
  - multipath -u: test socket connection in non-blocking mode
* Thu Apr 11 2019 mwilck@suse.com
- Update to version 0.7.3+114+suse.22c2357:
- Fix daemon shutdown issues (bsc#1110060, bsc#1110439)
  * multipathd: fix daemon not really shutdown
  * multipath: fix rcu thread cancellation hang
  * multipathd: check for DAEMON_SHUTDOWN in configure
  * multipathd: make DAEMON_SHUTDOWN a terminal state
- Other fixes
  * setup_map: wait for pending path checkers to finish
  (bsc#1118224)
  * multipathd: Fix miscounting active paths (bsc#1125043)
  * multipathd: fix device creation issues (bsc#1111116)
  * multipathd: fix irritating "minor number mismatch" message
  (bsc#1111116)
  * libmultipath: Increase SERIAL_SIZE to 128 bytes (bsc#1107179)
  * multipathd: avoid crash in cli_list_path (bsc#1121134)
* Mon Nov 26 2018 mwilck@suse.com
- Update to version 0.7.3+102+suse.be95116:
  * libmpathpersist: fix off-by-one error in PRIN length check
  (bsc#1099007)
* Wed Nov 14 2018 mwilck@suse.com
- Update to version 0.7.3+101+suse.beb7d7b:
  * multipathd: decrease log level of uevent messages (bsc#1110586)
  * libmultipath: pathinfo: skip hidden devices (bsc#1110586)
* Wed Oct  3 2018 mwilck@suse.com
- Update to version 0.7.3+99+suse.f3d8614:
  * multipathd: try SCSI persistent reservations for SCSI only
  (bsc#1108875)
  * libmultipath: allow sysfs_pathinfo to return SKIPPED (bsc#1098458)
  * multipathd: fix memory leak on error in configure (bsc#1110418)
  * multipathd: minor fixes (bsc#1110418)
  * multipathd: function return value tweaks (bsc#1110418)
  * libmutipath: don't use malformed uevents (bsc#1110418)
  * libmultipath: fix null dereference int alloc_path_group (bsc#1110418)
  * libmultipath: fix length issues in get_vpd_sgio (bsc#1110418)
  * libmultipath: fix gcc 8.1 "truncated output" warnings (bsc#1099007)
  * (lib)mpathpersist: use O_RDONLY file descriptors (bsc#1093220)
  * libmpathpersist: fix byte swapping for big endian systems (bsc#1099036)
  * libmultipath: add (get|put)_unaligned_be64 (bsc#1099036)
  * libmpathpersist: fix stack overflow in mpath_format_readfullstatus()
  (bsc#1099007)
  * libmpathpersist: fix typo in mpath_format_readfullstatus (bsc#1099007)
  * libmpathpersist: remove duplicate test in readfullstatus (bsc#1099007)
  * libmultipath: print correct default for delay_*_checks
  (bsc#1110418, bsc#1099026)
  * libmultipath: fix memory leak in process_config_dir() (bsc#1110352)
  * multipathd: register threads that use rcu calls (bsc#1110418)
  * multipathd: use nanosleep for strict timing (bsc#1110418)
  * libmultipath: fix log_pthread processing (bsc#1110418)
  * libmultipath: set dm_conf_verbosity (bsc#1110418)
  * libmultipath: fix basenamecpy (bsc#1110418)
  * libmultipath: get_uid: check VPD pages for SCSI only (bsc#1108728)
  * libmultipath: get_uid: don't quit prematurely without udev
  (bsc#1108728)
  * multipath: print sysfs state in fast list mode (bsc#1110354)
  * multipathd: release uxsocket and resource when cancel thread (bsc#1110355)
  * libmultipath: fix gcc 8.1 "truncated output" warnings (bsc#1099007)
* Thu Jun 28 2018 mwilck@suse.com
- Update to version 0.7.3+80+suse.6ccc1b0:
  * libmultipath: allow sysfs_pathinfo to return SKIPPED (bsc#1098458)
* Thu Jun 28 2018 mwilck@suse.com
- Update to version 0.7.3+79+suse.4b9f3ee:
  * multipath: don't start multipathd unnecessarily (bsc#1098177)
  * (lib)mpathpersist: use O_RDONLY file descriptors (bsc#1093220)
  * libmpathpersist: fix byte swapping for big endian systems (bsc#1099036)
  * libmultipath: add (get|put)_unaligned_be64 (bsc#1099036)
  * libmpathpersist: fix stack overflow in mpath_format_readfullstatus() (bsc#1099007)
  * libmpathpersist: fix typo in mpath_format_readfullstatus (bsc#1099007)
  * libmpathpersist: remove duplicate test in readfullstatus (bsc#1099007)
  * libmpathpersist: decrease log level of various messages (bsc#1099007)
  * Introduce the ibmultipath/unaligned.h header file (bsc#1099036)
  * libmultipath: Fix sgio_get_vpd() (bsc#1099484)
  * multipathd: fix reservation_key check (1099008)
  * libmultipath: avoid error messages from RDAC check (bsc#1075539)
* Thu Apr 12 2018 mwilck@suse.com
- Update to version 0.7.3+67+suse.8f0c27b:
  * disable nvme foreign library (bsc#1089353)
* Tue Apr 10 2018 mwilck@suse.com
- No functional changes
- Fixed rpmlint warnings (bsc#1088946)
  * multipath-tools-devel: moved .so files to /usr/lib[64]
  * added version dependencies for -devel packages
* Tue Apr 10 2018 mwilck@suse.com
- No functional changes
  * fixed SPDX syntax (and -> AND)
  * added /usr/share/licenses
* Tue Apr 10 2018 mwilck@suse.com
- No functional changes, just licenses
- Spec file: fix %%license tags and info after closer inspection
  (bsc#1088801)
  * kpartx is under GPL-2.0-only
  * rbd is under LGPL-2.1-only
- Update to version 0.7.3+66+suse.dc5fe2d: Fix licensing info (bsc#1088801)
  * Added fossology assessment as README.licenses
  * multipath-tools: create LICENSES dir with the text of all used licences
* Fri Apr  6 2018 mwilck@suse.com
- Update to version 0.7.3+61+suse.d4d0494:
  * 11-dm-mpath.rules: dont't run "multipath -U" during coldplug
  (bsc#1084748)
* Wed Mar 28 2018 mwilck@suse.com
- Fixed license tags in spec file
  * multipath tools / libmultipath is GPL-2.0-only
  * libmpathcmd is LGPL-2.0-or-later
  * libdmmp is GPL-3.0-or-later
  * adopt SPDX format.
* Wed Mar 28 2018 mwilck@suse.com
- Update to version 0.7.3+60+suse.46ac839:
  * libmultipath/hwtable: don't hard-code ALUA for IBM IPR
  (bsc#1085212, bsc#1075129)
* Wed Mar 21 2018 mwilck@suse.com
- Update to version 0.7.3+59+suse.1b6191c26774:
  * libmultipath: don't reject maps with undefined prio (bsc#1085212,
  bsc#1075129)
  * multipathd: handle errors in uxlsnr as fatal (bsc#1086025)
* Tue Mar 20 2018 mwilck@suse.com
- Update to version 0.7.3+57+suse.bb6be4c8b4ca:
  * multipathd: fix signal blocking logic (bsc#1086025)
  * multipath-tools: handle exit signal immediately (bsc#1086025)
  * multipath: fix DEF_TIMEOUT use (bsc#1086014)
  * multipath-tools: foreign/NVME implementation v2 (upstream accepted)
    (bsc#1082419)
* Mon Feb 26 2018 mwilck@suse.com
- Update to version 0.7.3+53+suse.140f4937e9e7:
  * libmultipath: fix wrong output of "multipath -t" (bsc#1082835)
* Thu Feb 22 2018 mwilck@suse.com
- Update to version 0.7.3+52+suse.08a969b7fce0:
- Add limited support for displaying native NVMe multipath
  (bsc#1082419)
  * libmultipath: foreign/nvme: implement path display
  * multipathd: use foreign API
  * multipath: use foreign API
  * libmultipath/foreign: nvme foreign library
  * libmultipath/print: add "%%G - foreign" wildcard
  * libmultipath: API for foreign multipath handling
  * libmultipath: print: use generic API for get_x_layout()
  * libmultipath: print: convert API to generic data type
  * libmultipath: "generic multipath" interface
  * libmultipath: add vector_convert()
  * libmultipath: add vector_free_const()
  * libmultipath: get rid of selector "hack" in print.c
- Fix locking errors detected by coverity check (bsc#1082418)
  * checkers/rbd: missing pthread_lock() on failure path
  * libmultipath: fix deadlock in tur.c
* Mon Feb 12 2018 mwilck@suse.com
- Fix whitespace in dracut conf file (bsc#1080562)
* Tue Jan 30 2018 mwilck@suse.com
- Update to version 0.7.3+38+suse.a16beed5280a:
  * kpartx: don't delete partitions from partitions (bsc#1078362)
  * hwtable: add latest updates (bsc#1078363)
  * multipathd.service: set TasksMax=infinity (bsc#1060616)
* Fri Jan 26 2018 mwilck@suse.com
- Update to version 0.7.3+31+suse.6804bb73f72d:
  * libmultipath: hwtable: no_path_retry="queue" for NetApp NVMe
  (bsc#1073319)
* Fri Jan 19 2018 mwilck@suse.com
- Update to version 0.7.3+30+suse.6b5ed839:
  * multipath.rules: temporary rule to obtain ID_WWN for NVMe
  (bsc#1076828)
  * libmultipath: ignore natively multipathed NVME devices
  (bsc#1076828)
  * multipath.rules: handle NVME devices (bsc#1076828)
  * FIX "libmultipath: hwtable: multibus for NetApp NVMe-FC"
  (bsc#1073319)
  * libmultipath: increase path product_id/rev field size for NVMe
  (bsc#1073319)
* Tue Jan 16 2018 mwilck@suse.com
- Update to version 0.7.3+25+suse.7c9920e2:
  * assemble_map: no newline at end of params string (bsc#1072253)
* Thu Jan 11 2018 mwilck@suse.com
- Update to version 0.7.3+24+suse.703a61d5:
  * multipathd.service: drop Before=lvm2-lvmetad.service (bsc#1070427)
  * libmultipath: hwtable: multibus for NetApp NVMe-FC
  (bsc#1073319)
  * libmultipath/propsel: select ALUA prioritizer for RDAC arrays only
  (bsc#1075539, bsc#1081241)
  * libmultipath: get_vpd_sgio: support VPD 0xc9 (bsc#1055949)
  * libmultipath: sgio_get_vpd: add page argument (bsc#1055949)
  * libmultipath: fix return code of sgio_get_vpd() (bsc#1055949)
* Fri Dec 22 2017 mwilck@suse.com
- Update to version 0.7.3+19+suse.0fd18bdd:
  * multipathd.socket: add WantedBy=sockets.target (bsc#1072253)
* Fri Dec 22 2017 mwilck@suse.com
- Update to version 0.7.3+18+suse.8c97f433:
  * multipath -C: decrease log level (bsc#1072504)
* Fri Dec 22 2017 mwilck@suse.com
- Update to version 0.7.3+17+suse.cac42e6f:
  * test-kpartx: add test for mapping without UUID
  (bsc#1074013)
* Wed Nov 29 2017 mwilck@suse.com
- Update to version 0.7.3+15+suse.570d5938:
  * kpartx.rules: fix by-id/scsi-* for user_friendly_names
  (bsc#1066893)
* Mon Nov 20 2017 mwilck@suse.com
- Update to version 0.7.3+14+suse.da06e7f3:
  * libmultipath: fix return code of sysfs_get_timeout (bsc#1069037)
* Mon Nov  6 2017 mwilck@suse.com
- added sample code for libmpathpersist (bsc#1066376)
  * added libmpathpersist-example.c
- multipath-tools.spec: package libmultipath.so symlink in -devel
  package (bsc#1066376). We *do not* package header files for
  libmultipath, as the APIs are not public.
* Fri Nov  3 2017 mwilck@suse.com
- multipath-tools.spec: package *.so symlinks in -devel pkgs
  (bsc#1066376)
- multipath-tools.spec: SLE15: add RADOS support for s390x
  (bsc#1066380)
- Fix build error for targets SLE_12, SLE_12_SP1
  (bsc#1066392)
* Thu Oct 26 2017 mwilck@suse.com
- Update to version 0.7.3+13+suse.db431514080f:
  * kpartx: create symlinks for dmraid devices (bsc#1064212)
  * limbultipath: prefer RDAC checker with detect_checker
  (bsc#1055949)
* Tue Oct 17 2017 hare@suse.com
- Update to version 0.7.3+11+suse.4de08d96:
  * libmultipath: condlog: log to stderr (bsc#1063059)
* Thu Sep 21 2017 mwilck@suse.com
- Update to version 0.7.3+10+suse.70ccb55b0439:
- Rebase to upstream release 0.7.3
  * libmultipath: add pthread_cleanup hook for udev monitor
  * libmultipath: pull functions into util.c
  * libmultipath: change reservation_key to a be64
  * libmpathpersist: fix update_prflag code
  * multipath: add alternate reservation_key method
  * mpathpersist: add support for prkeys file
  * multipath-tools: minor edition and corrections in multipath.conf.5
  * multipath-tools: fix incorrect length for strncmp in uevent.c
  * multipath-tools: clarify how to dump the multipathd config
  * multipath-tools: replace "setting: array" with "setting: storage device" at multipath output
  * libmultipath: sanitize fd handling
  * multipath-tools: link internal libraries before foreigns
  * multipath-tools: remove Sun StorEdge T4(6020,6120,6320) arrays from hwtable
  * multipath-tools: add support for all arrays from Sun StorEdge 3000 family
  * multipath-tools: add Xiotech iglu blaze arrays to hwtable
  * multipath-tools: add Dot Hill/Seagate arrays to hwtable
  * libmultipath: update INFINIDAT builtin config
  * multipath-tools: add info about adding new hardware
  * multipath-tools: Remove the limitation of IPC command reply length.
  * multipath-tools: libdmmp: Improve timeout mechanism
  * multipath-tools: libdmmp: New function to flush and reconfig
  * Bump version to 0.7.3
- minor fixes for upstream 0.7.3
  * libmultipath: ensure checker->fd == -1 if not set
  * libmpathpersist: add support for prkeys file v3
  * multipath: add man page info for my prkey changes
- Patch series for NVMe discovery and failover (bsc#1038865)
  * discovery: sanitize NVMe discovery
  * libmultipath/discovery: modify NVMe path states
  * Add 'none' checker
  * hwtable: set 'none' as default checker for NVMe
* Mon Sep 18 2017 mwilck@suse.com
- Update to version 0.7.2+49+suse.993a29b1188d:
  * Revert "11-dm-mpath.rules: Remember DM_ACTIVATION" (boo#1059227)
  * Revert "11-dm-mpath.rules: don't set READY->ACTIVATION"
  (boo#1059227)
  * multipath: delegate using libmpathcmd (bsc#1047639)
* Mon Sep 18 2017 mwilck@suse.com
- split off rados support into separate multipath-tools-rbd package.
  This avoids pulling in the whole rados/ibverbs/rdma stack with
  multipath-tools. (bsc#1058504).
- multipath-tools-rbd is Recommended but not Required by multipath-tools.
* Sat Sep  2 2017 mwilck@suse.com
- Update to version 0.7.2+44.3a8d750c:
  Misc bug fixes:
  * multipathd: don't flood system with sd_notify calls (bsc#1056011)
  * libmultipath: add_feature: skip pointless NULL check (bsc#1055635)
  * libmultipath: add_feature: allow only 1 feature (bsc#1055635)
  * multipath: delegate dangerous commands to multipathd (bsc#1047639)
  * libmultipath: fix partition_delimiter config option (bsc#1056526)
  * kpartx: helper functions for name and uuid generation (bsc#1056508)
  * kpartx: search partitions by UUID, and rename (bsc#1056508)
  * kpartx: fix a corner case when renaming partitions (bsc#1056508)
  * kpartx: -d must work with empty partition table (boo#1056599)
  * kpartx: only recognize dasd part table on DASD (boo#1056599)
  Rework of the udev rules related to multipath and kpartx (bsc#1054363):
  * libmultipath: support MPATH_UDEV_NO_PATHS_FLAG on map creation
  * libmultipath: add get_udev_device
  * libmultipath: get_refwwid: use get_udev_device
  * libmultipath: use const char* in some dm helpers
  * libmultipath: add DI_NOIO flag for pathinfo
  * libmultipath: add dm_get_multipath
  * multipath: implement "check usable paths" (-C/-U)
  * 11-dm-mpath.rules: multipath -U for READY check
  * 11-dm-mpath.rules: import more ID_FS_xxx vars from db
  * 11-dm-mpath.rules: no need to test before IMPORT
  * 11-dm-mpath.rules: handle new maps with READY==0
  * 11-dm-mpath.rules: don't set READY->ACTIVATION
  * 11-dm-mpath.rules: Remember DM_ACTIVATION
  * multipath.rules: set ID_FS_TYPE to "mpath_member"
  * kpartx.rules: don't rely on DM_DEPS and DM_TABLE_STATE
  * kpartx.rules: respect DM_UDEV_LOW_PRIORITY_FLAG
  * kpartx.rules: improved logic for by-uuid and by-label links
  * kpartx.rules: create by-partuuid and by-partlabel symlinks
  * kpartx.rules: generate type-name links only for multipath devices
  * kpartx.rules: fix logic for adding partitions
  * multipath/kpartx rules: avoid superfluous scanning
  * kpartx/del-part-nodes.rules: new udev file
  * kpartx.rules: move symlink code to other files
- multipath-tools.spec:
  * added 68-del-part-nodes.rules to support partition deletion
  * added 00-dont-del-part-nodes.rules to disable partition deletion
  by default on openSUSE/SLES for now.
  * added 11-dm-parts.rules to kpartx package
  * added dracut.conf file to make sure 11-dm-parts.rules is included
  in initrd
* Mon Aug 14 2017 mwilck@suse.com
- Update to version 0.7.2+14+suse.5721c345:
  * cli_add_map: Use CMD_NONE (bsc#1053515)
  * multipath-tools: link internal libraries before foreigns
  (bsc#1028132)
  * multipathd daemon: Fix incorrect use of CLOCK_MONOTONIC in
  pthread (bsc#1053757)
* Fri Aug 11 2017 mwilck@suse.com
- Update to version 0.7.2+11+suse.448921a2:
  * multipath.conf.5: document no_partitions compat support
  * libmultipath: fixup compat support for 'features "1 no_partitions"'
* Fri Aug 11 2017 mwilck@suse.com
- Dropped 67-kpartx-compat.rules (SUSE legacy).
  * symlinks "/dev/mapper/${UUID}_part${X}" are not created any more,
    only     "/dev/mapper/${UUID}-part${X}" (with "minus")
- Dropped automatic kpartx invocation on dmraid devices (fate#323743)
- Rebase to upstream multipath-tools 0.7.2:
  * libmultipath: retain_attached_hw_handler obsolete with 4.3+
  * multipath-tools: move up TEMPLATE in hwtable
  * multipath-tools: delete libdmmp/docs/man directory in make clean
  * libmultipath: fix unit to seconds in log message for checker timeout
  * multipath-tools: add HPE StoreVirtual 3200 family to hwtable
  * multipath-tools: add HPE MSA 2050/2052 to hwtable
  * multipath-tools: add/change fujitsu arrays
  * multipath-tools: check sysfs path state for NVMe/NVMf
  * multipath-tools: sync third-party headers with 3.13 upstream
  * multipath-tools: beautify path_latency.c code
  * multipath-tools: fix format in multipath.conf.5
  * libmultipath: update 3PARdata builtin config
  * Bump version to 0.7.2
- Update to version 0.7.2+8+suse.95e8f43e:
  * libmultipath: don't try to set hwhandler if it is retained
  (bsc#1037533)
  * libmultipath: don't [un]set queue_if_no_path after domap
  * kpartx/devmapper.h: remove dm_no_partitions
  * libmultipath: compat support for 'features "1 no_partitions"'
  (fate#323406)
  * kpartx.rules: respect DM_UDEV_LOW_PRIORITY_FLAG
  (bsc#1047180)
  * kpartx.rules: Use DM_ACTIVATION as condition (fate#323406)
  * kpartx.rules: skip creating by-uuid and by-label links
  (fate#32340)
* Thu Jul 20 2017 mwilck@suse.com
- Update to version 0.7.1+69+suse.3bfa5af1:
  * Merge branch 'sles12-sp3-fixes' into sles12-sp3
  * libmultipath: get_udev_uid: make sure pp->wwid is 0-terminated
  (bsc#1048146)
  * libmultipath: drop uevent_can_discard_by_devpath (bsc#1048052)
  * libmultipath: only listen for uevents with DEVTYPE=disk
  (bsc#1048052)
  * libmultipath: fix over-long NVME WWIDs
  (bsc#1048146)
* Tue Jun 27 2017 mwilck@suse.com
- Update to version 0.7.1+64+suse.aabe8c87:
  * Updated "no_path_retry" patchset to v4 (minor change)
  * kpartx.rules: Fix syntax error in skip_kpartx code (bsc#1046092)
- _service: use "match-tag" to refer only to offical tags
* Wed Jun 21 2017 mwilck@suse.com
- Update to version 0.7.1+62+suse.62a2c36e:
  * kpartx: only check for 'no_partitions' feature on dm devices
    (bsc#1037533)
  * Revert "kpartx: use mapname if no uuid is present"
    (bsc#1037533, bsc#1033541)
- "no_path_retry" patch series (bsc#1043027)
  * libmultipath: load_config: skip setting unnecessary defaults
  * libmultipath: add/remove_feature: use const char* for feature
  * libmultipath: clarify option conflicts for "features"
  * libmultipath: merge_hwe: fix queue_if_no_path logic
  * libmultipath: assemble_map: fix queue_if_no_path logic
  * multipath.conf.5: document no_path_retry vs. queue_if_no_path
  * multipath.conf.5: Remove ??? and other minor fixes
  * libmultipath: add deprecated warning for some features settings
- _service: Use "sles12-sp3" branch as revision, as factory
  and SLE12-SP3 submissions are in sync. Will be changed when
  factory forks off (latest at SLE12-SP3 GA).
* Tue Jun 20 2017 bwiedemann@suse.com
- set KBUILD_BUILD_TIMESTAMP to generate reproducible man-pages
  to fix build-compare (bsc#1045111)
* Wed Jun 14 2017 mwilck@suse.com
- Update to version 0.7.1+53+suse.07c2f6ac
- kpartx patch series from upstream (bsc#1037533, bsc#1033541)
  * kpartx: only check for 'no_partitions' feature on dm devices
  * kpartx: test-kpartx: new unit test program
  * kpartx: remove is_loop_device
  * kpartx: relax and improve UUID check in dm_compare_uuid
  * kpartx: dm_remove_partmaps: support non-dm devices
  * kpartx: dm_devn: return error for non-existent device
  * kpartx: don't treat multi-linear mappings as partitions
  * libmultipath: don't treat multi-linear mappings as partitions
  * kpartx: use partition UUID for non-DM devices
  * kpartx: use absolute path for regular files
  * kpartx: find_loop_by_file: use sysfs
  * kpartx: include sys/sysmacros.h
  * Revert "kpartx: relax check when checking for a kpartx device"
- Spec file: use new build flag for libdmmp installation
  (bsc#1036652), enabled by upstream fix:
  * libdmmp: enable library installation in alternative directory
- Other bug fixes from upstream:
  * libmultipath: print.c: make sure lines are 0-terminated (bsc#1038865)
  * multipath-tools: fix compilation with gcc < 4.9
  * kpartx: fix device checks
  * mpath_persist: Don't join threads that don't exist
  * libmultipath: fix suspended devs from failed reloads
  * mpathpersist: fix one more crash possiblity
- Minor upstream changes:
  * multipath: Merge the DELL MD3xxx device configs
  * multipath: fix up position independent code
  * libmultipath: fix partition detection (bsc#1037533)
  * kpartx: default to running in sync mode
  * libmultipath: force udev reloads
  * libmultipath: print alias with no_path_retry message
  * multipathd: force reload device on all resizes
  * libmultipath: refactor calls to get dm device info
  * multipath-tools: document uid_attribute for NVME devices
  * Makefile: Remove assignments to unused variables
  * libmultipath/configure.h: Add a forward declaration
  * libmpathpersist: Add two missing #include directives
  * Remove mpath_reverse_8bytes_order()
  * Move the declaration of mpath_mx_alloc_len to a header file
  * Remove a superfluous "extern" keyword
  * mpathpersist.8: add missing documentation for -K, -C, -l
* Thu Apr 27 2017 mwilck@suse.com
- spec file: Disable RADOS support for i586 on Leap 42.x (bsc#1036271)
- spec file: Move libdmmp to /usr/lib[64] (bsc#1036652)
- Update to version 0.7.1+7+suse.3edc5f7d:
  * kpartx: use mapname if no uuid is present (bsc#1033541)
  * kpartx: relax check when checking for a kpartx device (bsc#1033541)
  * libmpathpersist: use extern struct udev (bsc#1027188)
  * kpartx: include sys/sysmacros.h (fix compilation warning)
- Update to upstream version 0.7.1:
  * multipath-tools: improve processing efficiency for addition and deletion of multipath devices
  * uevent_can_discard: optimize devpath check
  * multipathd: fix SIGUSR2 handling
  * multipath-tools: clean up libdmmp/Makefile
  * multipath-tools: libdmmp: Fix incorrect use of __attribute__
  * multipath-tools: Remove trailing whitespaces
  * multipath-tools: add missing "-l" flag for pthread in libdmmp/Makefile
  * multipath-tools: build objects for libdmmp and libmpathpersist independently
  * libdmmp: minor Makefile cleanup
  * multipath-tools: remove incdir from Makefiles
  * libdmmp: don't disconnect from multipathd twice
  * multipathd: don't call strlen on NULL variables
  * libdmmp: move libdmmp.pc install location
  * multipathd: drop lock before calling uev_add_path
  * multipathd: allow devices to switch from RW to RO
  * libmultipath: don't set max_sectors_kb on reloads
  * Remove a trailing tab
  * multipath: fix segfault with disable_changed_wwids
  * multipath-tools: amend text from multipath/multipath.conf.5
  * Bump the version code and date
  * multipath-tools: replace multipath configuration output
  * Revert "multipathd: set timeout for CLI commands correctly"
  * libmultipath: fix skip_kpartx support for removing maps
  * Bump version to 0.7.1
* Fri Mar 24 2017 mwilck@suse.com
- spec file changes suggested by factory review team (bsc#1030699)
  * RPM group adjustments.
  * Avoid %%__ macro indirections
* Thu Mar 23 2017 mwilck@suse.com
- Enable rados for SLES only for x86_64 and aarch64 (ceph is currently
  disabled on SLES on s390x and ppc64le) (bsc#1030699)
- Downgrade to version 0.6.4+103+suse.bcb5d0f4:
  * temporarily remove commit "multipathd: fix SIGUSR2 handling"
  until it's merged in official repo (bsc#1030699)
* Tue Mar 21 2017 mwilck@suse.com
- Spec file: disable librados for architectures for which ceph
  is not built
- Spec file: enable librados by default for SLES12 SP3, disable
  it on Leap <= 42.1
- Update to version 0.6.4+104+suse.ac0df678:
  * multipathd: fix SIGUSR2 handling
* Fri Mar 10 2017 mwilck@suse.com
- Update to version 0.6.4+103+suse.bcb5d0f4:
  * changed to official github repo openSUSE/multipath-tools
    (no changes code-wise)
* Fri Mar 10 2017 mwilck@suse.com
- Spec file: Added dependency on sg3_utils (boo#1028857)
* Wed Mar  1 2017 mwilck@suse.com
- spec file changes: optional librados and libdmmp support
  * enabled by default on Factory and Leap
    (disable with --without-rados, --without-libdmmp)
  * disabled by default on SLES12
    (enable with --with-rados, --with-libdmmp)
  * libdmmp0_1_0 and libdmmp-devel as separate packages
  * minor fixes for RPMLINT warnings
- Update to version 0.6.4+102.0119472d:
  * rebased, code-wise identical to previous checkout
* Tue Feb 28 2017 mwilck@suse.com
- Update to version 0.6.4+102.df7d367e:
  * libmultipath/propsel: Do not select sysfs prioritizer for RDAC arrays
    (bsc#1004858)
* Tue Feb 28 2017 mwilck@suse.com
- Update to version 0.6.4+101.f01ef4da (SLES12 SP2 changes wrt upstream):
  * Make libdmmp build optional
  * multipath.rules: use -i flag to multipath
  * kpartx: create symlinks for dmraid devices
  * kpartx: Add udev compability rules for SUSE
  * libmultipath/checkers: make RADOS checker optional
  * multipathd: fixup check for new path states (bsc#1019798)
  * tur: Add pthread_testcancel() (bsc#101979)
  * kpartx: sanitize delete partitions (bsc#100869)
  * libmultipath: coalesce_paths: trigger uevent if nothing done
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: differentiate ACT_NOTHING and ACT_IMPOSSIBLE
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: reload map if not known to udev
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: sysfs_attr_set_value: use const char*
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: select_action: check special features separately
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: disassemble_map: treat aminio like assemble_map does
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: disassemble_map: skip no_path_retry check
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: setup_feature: handle "retain_attached_hw_handler"
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: setup_feature: print log msg if no_path_retry cant be set
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * libmultipath: setup_features: log msg if queue_if_no_path is ignored
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * multipathd: use weaker "force_reload" at startup
    (bsc#998906, bsc#998893, bsc#1005763, bsc#1011400)
  * multipathd: imply -n if find_multipaths is set (bsc#1012910)
  * multipath: ignore -i if find_multipaths is set (bsc#1012910)
  * libmultipath: move suspend logic to _dm_flush_map (bsc#986838)
  * multipath -ll: set DI_SERIAL (bsc#991432)
  * libmultipath: use existing alias from bindings file (bsc#1005255)
  * libmultipath/discovery: do not cache 'access_state' sysfs attribute (bsc#1004858)
  * multipathd: issue systemd READY after initial configuration (bsc#1006469)
  * multipath: avoid crash when using modified configuration (bsc#1000914)
  * multipathd: Set CLI timeout correctly (bsc#999061)
  * libmultipath: Do not crash on empty features (bsc#994812)
  * libmultipath: fall back to search paths by devt (bsc#995645)
  * multipathd: set timeout for CLI commands correctly (bsc#999061)
  * Invalid error code when using multipathd CLI
  * multipath: do not check daemon from udev rules (bsc#986734)
  * Add support for "multipath=off" and "nompath" on kernel cmdline
  * multipathd: start daemon after udev trigger (bsc#98673)
  * multipathd.service: fixup Wants= and Before= statements (bsc#1019181, bsc#991742, bsc#986734)
- Update to current upstream (0.6.4-65-ga2675025)
  * Avoid that reloading a map sporadically triggers I/O errors
  * fix udev rules for failed multipath devices
  * multipathd: allow resetting stats
  * multipathd: add messages on delayed path addition
  * multipathd: don't update priority of failed paths
  * libmultipath: cleanup orphan device states
  * libmultipath: add detect_checker option
  * kpartx: don't keep creating recursive partitions
  * multipath-tools: Introducing multipath C API
  * multipath-tools: sync valgrind.h with 3.12 upstream
  * multipath-tools: add availability of service-time and queue-length to multipath.conf.5
  * multipath-tools: add availability of service-time and queue-length to multipath.conf.5
  * Fill NVMe specific path info
  * Don't blacklist nvme
  * multipath-tools: fix misspellings
  * multipath-tools: git should ignore rej and orig files
  * Include sys/sysmacros.h
  * Tolerate modprobe failures in multipathd.service
  * multipath-tools: Remove trailing and leading whitespaces
  * multipath-tools: Perform socket client uid check on IPC commands.
  * multipath-tools: Set errno mpath_recv_reply() when failure
  * multipath-tools: New way to limit the IPC command length.
  * multipath-tools: libmultipath: Removed unused functions.
  * multipath-tools: libmultipath: fix gcc link failure on rcu_register_thread_mb.
  * multipath-tools: multipathd: Fix memory leak on load_config().
  * [multipathd] Remove trailing whitespaces
  * multipathd: deterministic io throughput in multipath
* Sat Feb 18 2017 kukuk@suse.com
- Remove superfluous PreReq for insserv and fillup
* Thu Sep 29 2016 mwilck@suse.com
- Update to version 0.6.2+suse20160928.8939fb6
* Thu Sep 29 2016 hare@suse.de
- Implement support for 'multipath=off' and 'nompath'
  kernel commandline options (bsc#1001691)
* Wed Sep 28 2016 hare@suse.de
- multipath: avoid crash when using modified configuration
  (bsc#1000914)
* Mon Sep 19 2016 hare@suse.de
- libmultipath: Do not crash on empty features (bsc#994812)
- multipathd: Set CLI timeout correctly (bsc#999061)
- Moved multipath-tools repository to
  github.com:/openSUSE/multipath-tools.git
* Thu Sep  8 2016 hare@suse.de
- Fixup glitch from patch 'fixup check from udev rules' (bsc#986734)
- Remove 0001-libmultipath-fall-back-to-search-paths-by-devt.patch;
  integrated into git repository
* Mon Aug 29 2016 jthumshirn@suse.com
- libmultipath: fall back to search paths by devt (bsc#995645)
* Fri Aug 26 2016 hare@suse.de
- Fixup module name in /usr/lib/modules-load.d (bsc#986734)
* Fri Aug 26 2016 hare@suse.de
- multipath: fixup check from udev rules (bsc#986734)
* Wed Aug 24 2016 hare@suse.de
- multipathd: start daemon after udev trigger (bsc#986734)
- Load device handler and multipath module at boot (bsc#991634)
* Fri Aug 19 2016 hare@suse.de
- Do not check daemon from udev rules (bsc#986734,bsc#990538)
* Fri Aug  5 2016 hare@suse.de
- Include fixes from upstream:
  * memory leak in orphan_paths
  * More hardware table cleanups
  * Add 'serial' keyword to weightedpath prioritizer
- Set timeout for CLI commands correctly (bsc#990265)
- Start daemon after udev trigger (bsc#991742,bsc#986734,bsc#990538)
- multipathd.service: Fixup Wants= and Before= statements
  (bsc#991742, bsc#986734)
* Thu Jul 28 2016 hare@suse.de
- Include patches from upstream:
  * Cleanup hardware tables by removing default entries
  * More formatting fixes
  * Order keywords in multipath.conf.5
  * Change default pgpolicy from 'failover' to 'group_by_prio'
  * kpartx: Fix check whether to detach a loop device
  * Fix partly traversed loop in coalesce_paths()
  * Fix memory leak in reconfigure()
  * Cleanup include header files
  * Bump version code to 0.6.2
- Fix multipath -l <devmap> without output (bsc#990480)
- Fix spelling in a log message
- Fix type of rcu_unregister()
- Do not perform POSIX mutex operations inside a signal handler
- Ensure that signals are delivered to the uxsock thread
- Fix memory leak in path group policies
- Update tarball to 0.6.2+suse20160728.d96f423
* Fri Jul 15 2016 hare@suse.de
- Include patches from upstream:
  * Makefile cleanup
  * Update multipath.conf.5
  * Update hardware tables
  * Whitespace cleanup
- Fixup crash during shutdown (bsc#988539)
- Update tarball to 0.6.1+suse20160715.3d44636
* Mon Jul  4 2016 jengelh@inai.de
- Remove obsoletes spec sections
* Mon Jul  4 2016 hare@suse.de
- Move config accesses to use user-space RCU (bsc#987526)
  * Revert 'move filter_devnode under vector lock'
  * Revert the rework patch
- Include patches from upstream:
  * Update hardware tables
  * Update kpartx manpage
  * Whitespace fixes
  * Include coverity fixes
  * Drop AUTHOR file
- Update tarball to 0.6.1+suse20160704.6e52398
* Wed Jun  8 2016 lnussel@suse.de
- fix service file to not pretend that this is the upstream version.
  Now labeled 0.6.1+suse20160603.9b920e3
- Fix BuildRequire to get systemd.pc from correct package (bsc#983167)
- point rcmultipathd to /usr/sbin/service to avoid dangling symlink warning
* Fri Jun  3 2016 hare@suse.de
- Rework patch 'move filter_devnode under vector lock'
  (bsc#982348)
* Mon May 30 2016 hare@suse.de
- multipathd: Fixup definition of set_unlocked_handler_callback()
- mpathcmd.h: Update Free Software Foundation address
* Fri May 27 2016 hare@suse.de
- Do not install header file with mode 755
* Wed May 25 2016 hare@suse.de
- Update to latest upstream version 0.6.1
  * Merge suse-specific patches
  * Drop multipath.conf.* files
  * Update to version 0.6.1
  * multipathd: move 'filter_devnode' under vector lock
  * libmultipath: use poll() in uevent_listen()
  * Increase kpartx retries
  * Merge Dell MD3XXX hardware table entries
  * multipathd: Add 'sysfs' prioritizer (bsc#927040)
  * libmultipath: call get_vpd_uid() if no uid_attribute is set
  * multipathd: update defaults
* Fri May  6 2016 hare@suse.de
- Update to latest upstream version 0.6.0 (FATE#319406)
  * Update documentation
  * Fix memory leak and segfault in reconfigure
  * Add wwn keyword to weightedpath prioritizer
  * Use 64-bit int for command key
  * check partions unused before removing
  * print 'fail' when remove fails
  * add exclusive_pref_bi for alua prioritizer
  * kpartx: verify parition devices
  * multipathd: delay reloads during creation
  * Cut down alua prioritizer ioctls
  * Add 'ignore_new_boot_devs' option
  * Add libmpathcmd library and use it internally
  * retrigger uevents to try and grab uid
  * Update to version 0.6.0
* Fri Apr 15 2016 hare@suse.de
- Port to latest upstream version (FATE#319406, FATE#320255)
  * kpartx: support device names with spaces
  * add raw format multipathd commands
  * make kpartx -d remove all partitions
  * Add find_multipaths option
  * Autodetect ALUA CLARiiON configurations
  * Delayed path reintegration
  * enable configuration directory
  * read-only bindings
  * Add deferred_remove support
  * correctly set partition delimiter on rename
  * Add overrides section to multipath.conf
  * Add additional path wildcards
  * Add force_sync option
  * Misc small patches
* Thu Mar 24 2016 hare@suse.de
- multipathd: do not flush maps on startup
- Use find_path_by_dev() where possible (bsc#924316)
- Fixup error return in store_path() (bsc#972329)
- Do not display message 'invalid fd'
* Tue Mar  8 2016 hare@suse.de
- Fixup overzealous warning 'empty device number' (bsc#969857)
* Wed Feb 17 2016 hare@suse.de
- multipathd: fixup signal handling (again)
- Revert 'trigger all devices on startup'
- multipathd: print error message for invalid arguments
- multipathd: block checkerloop during reconfiguration (bsc#946658)
- libmultipath: correctly initialize pp->sg_id
- multipathd: don't buffer output with systemd (bsc#954726)
- multipath.rules: Do not forward partition events (bsc#954726)
- libmultipath: improve uxlsnr handling (bsc#954726)
- multipathd: do not realloc memory in uxlsnr (bsc#954726)
- libmultipath: call get_uid() for all paths (bsc#935312)
- multipathd: Do not print misleading message 'not found in pathvec'
- multipathd: Do not update the paths vec when removing paths
- multipathd: Do not switch paths on empty multipath tables (bsc#956349)
- libmultipath: remove 'get_info' argument for adopt_paths()
- libmultipath: ensure 'dev_t' is set when store paths (bsc#924316)
- libmultipath: Do not store paths with empty dev_t (bsc#924316)
- libmultipath: Do not store paths with empty device name (bsc#924316)
- libmultipath: sysfs_set_rport_tmo still wrong (bsc#926588)
- Add LIO-ORG/SUSE RBD backend hardware defaults (bsc#947845)
- multipath: Reset alias if renaming fails (bsc#943157)
* Fri Nov  6 2015 hare@suse.de
- Fixes for md_monitor on zFCP (FATE#319070):
  * strict loop timings
  * multipathd: fixup a crash when invoking CLI commands
  * multipathd: implement 'show map $map format $format
* Tue Aug 25 2015 hare@suse.de
- Fixup hang in 'multipath -f' (bsc#941954)
* Mon Aug  3 2015 hare@suse.de
- Create package for SLE12-SP1.
  * Remove multipath-tools-0.5.0-sles12.diff.bz2
  * Add multipath-tools-0.5.0-sles12-sp1.diff.bz2
- kpartx: parse emulated DASD devices
- multipathd: Fixup queueing mode in 'show maps status' (bsc#933885)
- multipathd: Accept zero-sized paths in ev_add_path
- Always set DM_UDEV_DISABLE_LIBRARY_FALLBACK (bsc#933282)
- libmultipath: Fixup 'DM_DEVICE_RELOAD' handling (bsc#933282)
- libmultipath: correctly display checker status
* Wed Apr  8 2015 hare@suse.de
- Remove 'udev_sync' argument from dm_simplecmd (bsc#903001)
- Ensure multipathd is started before systemd-udev-trigger
* Tue Apr  7 2015 hare@suse.de
- Only import ID_FS_XXX variables if not set (bsc#909358)
- Fixup regular expression for HP MSA 2040 (bsc#920189)
* Wed Mar 18 2015 hare@suse.de
- Add dependency on systemd-udevd.service (bsc#903001)
- Use ALUA for HP 3PAR (bsc#922105)
- Add DX8700 S3 and DX8900 S3 defaults (bsc#921703)
- Load all device handler modules on startup (bsc#908529)
* Fri Mar 13 2015 hare@suse.de
- libmultipath: make vpd page 0x80 optional (bsc#917963)
- Add HP MSA 2040 to the hardware table (bsc#920189)
- Revert 'Skip unhandled device types' (bsc#917701)
* Thu Jan 29 2015 hare@suse.de
- skip uninitialized devices during reconfiguration (bnc#908915)
- memory overflow when printing help text (bnc#909742)
* Tue Dec 16 2014 hare@suse.de
- Do not automatically fall back to vpd uid generation
- Improve vpd parsing
- multipathd: trigger all devices on startup (bnc#901465)
- Unset 'uid_attribute' on failure
* Wed Dec 10 2014 hare@suse.de
- libmultipath: Fall back to SG_IO if no UID could be assigned
  (bnc#908915)
- Assign local priority for NAA VPD descriptor (bnc#907483)
- libmultipath: finally fix dev_loss_tmo setting (bnc#889927)
- libmultipath: Do not use 'sscanf' for parsing integers (bnc#889927)
- devmapper: do not flush I/O for DM_DEVICE_CREATE (bnc#901809)
- kpartx: handle more than 256 loop devices (bnc#898427)
- multipathd: fixup locking in uev_remove_map() (bnc#901891)
- multipathd: use global variable for uxsock timeout (bnc#900758)
- multipathd: remove unused variable in cli_reconfigure()
- Add %%service calls for multipathd.socket
* Mon Sep 22 2014 hare@suse.de
- Really fix segfault in recv_packet (bnc#896678)
- Allow empty revision during discovery (bnc#896864)
* Wed Sep 17 2014 hare@suse.de
- Fix segfault in recv_packet (bnc#896678)
* Wed Sep  3 2014 hare@suse.de
- Fixup segfault due to double unlock
- Skip USB devices during discovery (bnc#865577)
- Ignore devices when sysfs_get_tgt_nodename fails (bnc#865577)
- Use sysfs attribute vpd_pg80 to read serial number
* Wed Sep  3 2014 hare@suse.de
- Create rcmultipathd links (bnc#894513)
- multipathd: fix segfault in checkerloop() (bnc#894513)
- Use regenerate_posttrans rpm macros (bnc#892181)
* Tue Sep  2 2014 trenn@suse.de
- Do not call mkinitrd in rpm macros directly, make use of
  %%{?regenerate_initrd_posttrans} and %%{?regenerate_initrd_post}
  instead to avoid rebuilding of initrd for each package that
  needs initrd recreation. Only update initrd once per install/update
  if needed
* Fri Aug 29 2014 hare@suse.de
- Fixup segfault during uev_path_add() (bnc#892214)
* Thu Aug 21 2014 hare@suse.de
- Revert to ACT_RELOAD in domap() if the map exists
- multipathd: asynchronous configuration (bnc#891189)
- multipathd: timeout CLI commands when waiting for lock
  (bnc#891189)
- Remove dm_udev_XXX wrapper functions
- uxlsnr: use typedef for trigger function
- multipathd: lock cli client list
- multipathd: Use standard lists for CLI handling
* Tue Aug 19 2014 hare@suse.de
- Use strlen() when checking for valid wwid
- kpartx: zero out cookie (bnc#890902)
- multipathd: Check for empty wwid when processing events
  (bnc#892214)
* Mon Aug 18 2014 hare@suse.de
- Fixup device-mapper cookie handling yet again (bnc#890902)
- Allow zero-sized devices during configuration
- multipathd: issue warning on CLI command timeout (bnc#891189)
* Wed Aug 13 2014 hare@suse.de
- Do not remove paths without uevent (bnc#890998)
* Tue Aug 12 2014 hare@suse.de
- Fixup structure misalignment in config.h (bnc#890747)
- Do not print empty multipaths section
- Fixup 'uxsock_timeout' handling
- Reload map if reinstate failed (bnc#890854)
* Mon Aug 11 2014 hare@suse.de
- Close memory leak in print_multipath_topology
- Implement 'uxsock_timeout' keyword (bnc#890551)
- Return error when receiving CLI packet (bnc#890551)
- multipath: do not print state 'orphan' for option '-l' (bnc#890551)
- Fix race conditions during uevent processing (bnc#890994)
* Tue Aug  5 2014 hare@suse.de
- Skip unhandled device types (bnc#881125)
- use 'uid_attribute' per default when generating WWID (bnc#881125)
- Use a default dev_loss_tmo of 600 (bnc#889927)
- Fixup device-mapper 'cookie' handling (bnc#886743)
- Remove last argument from verify_paths()
- Add paths with a size of '0' as 'ghost' paths
- Remove sysfs_get_dev()
- Use glibc 'major' and 'minor' macros
- Whitespace cleanup in mpath_persist
* Mon Jul 28 2014 hare@suse.de
- Fixup wrong check for errno in uevent_listen()
  (bnc#889165)
- Terminate uevent listener on ppoll() error (bnc#889165)
* Fri Jul 25 2014 hare@suse.de
- Patches from upstream:
  * enable gcc format-security check
  * Accept "*" as a valid regular expression
  * check info.exists to get valid value
  * Don't forget to reload table when both reload and rename
    is required
  * libmultipath: Simplify read_line()
  * libmultipath: Zero-terminate sysfs_attr_get_value() result
  * libmultipath: Print line number for which parsing failed
  * libmultipath: Accept "*" as a valid regular expression
  * multipath: Wrong sysfs attribute used for iSCSI settings
    (bnc#883808)
- Check for valid DM_DEVICE_INFO before proceeding
  (bnc#888453)
- Scalability fixes (bnc#880356):
  * Separate out uevent parsing functions
  * Use poll() when receiving uevents
  * multipathd: push down lock in checkerloop()
  * Allow specific CLI commands to run unlocked
  * Push down vector lock during uevent processing
* Wed Jul 23 2014 hare@suse.de
- recovery_tmo for iSCSI sessions not updated (bnc#883808)
- Only filter for udev property if uid_attribute is present
- Read wwid from sysfs vpg_pg83 attribute
- Update multipath.conf.5 to clarify wwid generation
- kpartx: Fixup persistent name generation (bnc#887582)
- Revert 'return PATH_DOWN for quiesced paths'
- Do not treat 'transport-offline' paths as 'offline' (bnc#888378)
* Wed Jul  9 2014 hare@suse.de
- multipath: Check for running daemon when called with '-u'
  (bnc#886154)
* Fri Jul  4 2014 hare@suse.de
- multipath: use option '-i' when called from udev (bnc#885628)
- multipath: add option '-i' to ignore wwids file (bnc#885628)
- Update hwtable for EMC XtremIO (bnc#880510)
- Remove unused variable 'aas' from alua prioritzer
- Patches from upstream:
  * Add multipath.conf force_sync option
  * make prioritizers use checker_timeout, if set
  * Improve multipath.conf syntax checking
  * orphan paths on failed add
  * Add missing interactive commands to multipathd man page
  * Make multipathd orphan paths that were removed externally
  * allow users to add wwids to /etc/multipath/wwids with -a
  * change conf->dry_run to conf->cmd
  * Return the correct size buffer in set_value()
  * Fix memory issues in path reordering failure code paths
* Tue Jun 24 2014 hare@suse.de
- Fixup race condition with udev (bnc#883878)
- Cleanup foreground operation handling in multipathd
- Fix some minor issues in path reordering code (bnc#870465)
- Patches from upstream:
  * Use existing user friendly names if possible
  * kpartx: fix extended partition size for >512b sectors
  * Mismatch between allocation length and transfer length in
    rdac prio
  * Mismatch between allocation length and transfer length in
    emc_clariion prio.
* Fri Jun 13 2014 hare@suse.de
- 11-dm-mpath.rules: Import blkid values if all paths are down
  (bnc#875233)
- kpartx.rules: Skip kpartx for multipath events (bnc#875233)
* Tue May 20 2014 hare@suse.de
- Fix race condition with systemd (bnc#878809)
* Fri May 16 2014 hare@suse.de
- Fix segfault when fast_io_fail_tmo is empty in config file
- Crafted ordering of child paths for round robin path selector
  (bnc#870465)
- multipath: enable sync support (bnc#872297)
- Whitelist devices in multipath.rules (bnc#877281)
* Fri Apr 11 2014 hare@suse.de
- Install multipath rule under 56-multipath.rules (bnc#873151)
- Implement option '-u' for uevents (bnc#873151)
- Remove trailing linefeed from sysfs attributes
- Make checker_put() and prio_put() idempotent
- Implement 'list path' CLI command
- Disable reassign maps per default
- Allow for NULL path when printing information
- Fixup wwid blacklist printing
- Use SCSI_IDENT_.* as the default property whitelist (bnc#872929)
- Do not call 'blkid' in kpartx.rules
- Allow empty wwids during discovery (bnc#872712)
- Always set verbosity to '0' when checking devices (bnc#867840)
- Fixup multipath rules for booting (bnc#870764)
- Fixup dependencies in multipathd.service (bnc#872712)
- Do not print empty device strings during discovery (bnc#872712)
- Use multipath wwid if path wwid is empty (bnc#872712)
- Set the correct PID when running in debug mode
* Fri Mar 21 2014 hare@suse.de
- Fixup ordering cycle with systemd (bnc#863218)
- Rebase git repository to match with upstream
- Revert 'display uevent sequence number'; not required anymore
* Wed Mar 12 2014 ro@suse.de
- downgrade device-mapper requirement to 1.2.78 until 1.2.82
  is available anywhere
* Wed Mar 12 2014 hare@suse.de
- Update FSF address
- Add 11-dm-mpath.rules (bnc#867968)
- Link against libsystemd instead of libsystemd-daemon
* Fri Feb 28 2014 hare@suse.de
- Fixup spec file to correct rules permissions
* Fri Feb 28 2014 hare@suse.de
- Fixup 40-multipath.rules installation
* Wed Feb 26 2014 hare@suse.de
- Add 40-multipath.rules for dracut support
* Fri Feb 14 2014 hare@suse.de
- Install kpartx rules with correct prefix for dracut
- filter for missing property in get_refwwid() (bnc#862250)
- Double uevent stacksize yet again (bnc#855379)
- do not fail discovery on individual devices (bnc#860850)
- Prefer deprecated 'getuid' callout (bnc#861534)
- Skip paths with empty wwid (bnc#861534)
- correctly terminate string in strlcpy() (bnc#861534)
- Don't chop const strings
- Fixup typo in Makefile
- display uevent sequence number on 'show daemon'
* Tue Jan 21 2014 hare@suse.de
- Fixup build issues
* Tue Jan 21 2014 hare@suse.de
- Update to official version 0.5.0
  - remove: multipath-tools-0.4.9.tar.bz2
  - remove: multipath-tools-0.4.9-opensuse-12.3.diff.bz2
  - add: multipath-tools-0.5.0.tar.bz2
  - add: multipath-tools-0.5.0-sles12.diff.bz2
- Merge:
  - multipath-tools-make-flexible-install-of-systemd-and-udev-files.patch
* Tue Apr 16 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
  - use %%setup -c to support the tarball
* Fri Feb 15 2013 cfarrell@suse.com
- license update: GPL-2.0
  Substantial number of GPL-2.0 files in the package
* Fri Feb 15 2013 rmilasan@suse.com
- Make installation of systemd unit and udev files more flexible.
  add: multipath-tools-make-flexible-install-of-systemd-and-udev-files.patch
* Fri Feb  1 2013 hare@suse.de
- Update to latest mainline git version
- Merge systemd fixes
- Generate persistent device names for kpartx (bnc#799274)
* Sun Aug 26 2012 crrodriguez@opensuse.org
- Systemd: use default service type instead of forking
- Systemd: fix spec pre/post scripts.
* Tue Jul 17 2012 rmilasan@suse.com
- Drop patch 0001-multipath.rules.patch, multipath not ready yet.
* Tue Jul 17 2012 rmilasan@suse.com
- Fix the installation of multipath.rules file.
* Mon Jun 11 2012 rmilasan@suse.com
- Drop RUN+="socket:..." and update the multipath.rule like Fedora
  does.
* Wed May 30 2012 hare@suse.de
- Update to version 0.4.9
- Merge in latest changes from mainline
* Fri Apr 20 2012 rmilasan@suse.com
- Run update of initrd at %%post and %%postun.
  We need this to make sure initrd reflects the updates.
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Fri May 27 2011 lnussel@suse.de
- don't hard require boot.device-mapper in boot.multipath. dm-mod is
  autoloaded when accessing /dev/mapper/control anyways.
* Mon Apr  4 2011 crrodriguez@opensuse.org
- fix build fail with AS_NEEDED by default
* Fri Nov 26 2010 meissner@suse.de
- updated one more dm_simplecmd caller with &cookie.
- bumped 1 character buffer to 1 byte more for leading \0
* Tue Jul  6 2010 hare@suse.de
- Merge with fixes from mainline.
* Wed Jun 30 2010 jengelh@medozas.de
- fix compilation on bi-arch by specifying LIB=%%_lib
  (Makefiles would erroneously assume a 64-bit target just by the
  sheer presence of lib64, which is wrong)
- always add in -D_GNU_SOURCE to get at struct ucred
* Wed Jun 23 2010 hare@suse.de
- Increase initial timeout for 'tur' checker (bnc#616694)
* Fri Jun 18 2010 hare@suse.de
- Set geometry information for multipath maps (bnc#613363)
- Reset 'running' parameter for directio (bnc#600043)
- Add fallback to init script for older versions (bnc#602957)
* Fri Jun  4 2010 hare@suse.de
- Add HP 2000 to internal hardware table (bnc#603359)
- Make path state messages unique
- Add 'reassign_maps' configuration parameter
- Profiling fixes:
  * Update 'max_fds' handling
  * Use strcmp() instead of strcmp_chomp()
  * Simplify sysfs_get_device()
  * Remove duplicate calls to path_offline()
  * Simplify dm_get_name()
  * Fixup devt2devname()
  * Rework dm_reassign()
- check argument length in execute_program(bnc#610914)
- Do not use LOG_CONS when opening syslog (bnc#610914)
- Remove pid file usage from init scripts (bnc#600412)
- Fixup boot.multipath init script (bnc#600412)
* Wed May 12 2010 hare@suse.de
- Always provide symlinks for udev (bnc#603785)
* Thu May  6 2010 hare@suse.de
- Use minor number in ev_remove_map() (bnc#599770)
- signal_waiter() overwrites structure (bnc#591399)
- Serialize startup on large machines (bnc#598697)
- Update multipath(8) manpage for '-p' (bnc#602970)
- Mark 'readsector0' checker as deprecated (bnc#589340)
* Mon Apr 26 2010 hare@suse.de
- Errorneous message 'error starting uevent listener'
- Graceful shutdown of logging thread (bnc#591399)
* Mon Apr 26 2010 hare@suse.de
- Missing '-p' option for mkdir in mkinitrd script (bnc#597786)
- rdac message not printed correctly (bnc#598302)
- Use alias when printing log messages (bnc#598302)
- valgrind fixes (bnc#591399)
- Use VECTOR_SIZE() defines
- Update hwtable factorization
- Use log_close() on shutdown
- Use refcounting for checkers (bnc#591399)
- More valgrind fixes
* Tue Apr 20 2010 hare@suse.de
- Provide correct persistent symlinks for user_friendly_names
  (bnc#596301)
- Fixup hardware table for LSI arrays (bnc#597713)
- Reassign maps during startup (bnc#586834)
- Update manpage
* Tue Apr 20 2010 mmarek@suse.cz
- Use mkdir -p in mkinitrd setup script (bnc#597786).
* Fri Apr  9 2010 hare@suse.de
- Remove 'minor' argument from add_map_without_path
- Check for correct device-mapper device in uevent handler
- Start uevent service handler from main thread
- Do not reassign multipath maps (bnc#594341)
- Protect waiter structure by mutex (bnc#581200)
- Log directly to syslog on shutdown (bnc#581200)
- Clear up uevent queue on shutdown
- Add more IBM/FAStT arrays (bnc#578738)
* Mon Mar 29 2010 hare@suse.de
- Display average priority as group priority (bnc#588591)
- Implement 'wait event' cli command (bnc#586834)
- Reset existing maps (bnc#577894)
* Mon Mar 15 2010 hare@suse.de
- Setup 'checkint' when loading config file (bnc#586847)
* Wed Mar 10 2010 hare@suse.de
- Fix typo in persistent rules for by-label/by-uuid
- Update debug string in verify_paths()
- Evaluate feature setting in verify_paths() (bnc#584197)
* Fri Mar  5 2010 hare@suse.de
- Fixup 'async_timeout' initialization again (bnc#580413)
* Fri Feb 26 2010 coolo@novell.com
- fix buffer overflow in strncat
* Mon Feb 22 2010 hare@suse.de
- 'reset log' cli command crashes daemon (bnc#577889)
- Initialize 'async_timeout' variable correctly (bnc#580413)
* Thu Feb  4 2010 hare@suse.de
- Add hardware defaults for EMC Invista (bnc#573870)
- Use '--replace-whitespace' for scsi_id (bnc#572209)
- Asynchronous mode for tur checker (bnc#552688)
- Update queue_if_no_path after sync with kernel state
  (bnc#570932)
- Add 'max_polling_interval' config variable (bnc#570932)
- Add 'async_timeout' configuration variable (bnc#570932)
- Use default scsi_id callout for EMC Symmetrix (bnc#528481)
- Update path_offline() to return device status
- Update filename in init script
- Fixes from upstream:
  * do not allow 0 size for multipath devices
  * Add nexenta comstart hardware defaults
  * Add checks for conf->xxx
  * Add %%z wildcard to display path serial
  * don't pretend config file has setup parameters
  * documentation fixes
* Mon Jan 25 2010 hare@suse.de
- Fixup kpartx initrd script to handle loop devices (bnc#523749)
- Switch off 'queue_if_no_path' before removing maps (bnc#475523)
- Update logical partition handling (bnc#551827)
* Fri Jan 22 2010 hare@suse.de
- Fix mkinitrd scripts for 64bit (bnc572143)
- Remove logical partitions maps with 'multipath -f'
* Fri Jan 22 2010 ro@suse.de
- testing for existence of /lib64 is not sufficient to find out
  if we are building for a lib64 platform
* Mon Jan 11 2010 hare@suse.de
- Update dev_loss_tmo for no_path_retry (bnc#492469)
* Tue Nov 17 2009 hare@suse.de
- Merge in changes from OpenSUSE 11.2
- Update 'no_path_retry' correctly for failed paths (bnc#534666)
- Update no_path_retry setting when evaluating features (bnc#542145)
- directio: block count calculation wrong (bnc#549028)
- multipath segfaults if configuration file contains errors
  (bnc#540118)
* Thu Oct 22 2009 hare@suse.de
- Make 'param' local (bnc#548708)
- Include multipath-fix.patch in git tree.
* Mon Sep 28 2009 hare@suse.de
- Fixup strip whitespaces from getuid output (bnc#542085)
- Change prefix for DASD devices to 'ccw'
- Update no_path_retry setting when evaluating features (bnc#542145)
* Wed Sep 16 2009 hare@suse.de
- Update features when queue_if_no_path is set (bnc#511607)
- Ignore error messages when multipathd is not started
- Add debugging output for feature changes
- Add generic LSI/Engenio controller (bnc#508030)
- Update 'no_path_retry' correctly for failed paths (bnc#534666)
- TUR checker should not return 'failed' for reservation conflict
  (bnc#498413)
* Tue Sep  8 2009 aj@suse.de
- Fix last patch, one caller of dm_simplecmd was not updated
  (multipath-fix.patch).
* Fri Aug 21 2009 hare@suse.de
- Update to latest upstream git version
- Merge in SLES11 fixes
- Build package from git tree
- Implement '-u' option for kpartx (bnc#517442)
* Mon Jul 13 2009 hare@suse.de
- Check for errors in pthread_create()
- Lock vectors during shutdown
- Cleanup various MALLOC/REALLOC callers
- Fix multipathd crash on shutdown
- Do not run kpartx on dm-uevent messages (bnc#473352)
- Set pthread stacksize correctly (bnc#485287)
- Add STK arrays to internal hardware table (bnc#503855)
- Correct persistent symlink for cciss (bnc#497997)
- Backport some fixes from upstream (bnc#445023)
- Add 'reset log' cli command
- no_path_retry <N> causes I/O to fail (bnc#485281)
- Terminate uevent service queue
- Wait for daemon to shutdown (bnc#481389)
- Update cli request processing
- Safe memory allocation in cli_handlers
- Use 'LOG_CONS' option for openlog()
- Remove sysfs attribute cache
- Add 'shutdown' cli command
- Display FC error messages correctly
- Wait for devices in init script (bnc#487586)
- Always synchronize with dm state (bnc#447887)
- Add 'aas' path prioritizer (bnc#472069)
- Synchronize daemon startup with init file (bnc#481389)
- Merge feature string in assemble_map (bnc#507793)
  - ------------------------------------------------------------------
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Fri Mar 20 2009 hare@suse.de
- Reset checker message for blocked checkers
- Increase priority for EMC Clariion arrays (bnc#484529)
- Start waiter threads for single paths correctly (bnc#473841)
- Use pthread_sigmask in alias.c when called from daemon.
* Thu Mar 19 2009 hare@suse.de
- Add %%pre and %%post scripts to stop multipathd during update
- Don't set FC parameter on non-SCSI devices
- multipath -t crashes with invalid configuration file
* Fri Mar 13 2009 hare@suse.de
- Don't remove partition mappings on stop (bnc#468826)
- Set stacksize for log thread
- Terminate all I/O before flushing maps (bnc#475523)
- Select 'features' keyword from multipath setting (bnc#465009)
* Tue Mar 10 2009 hare@suse.de
- Use lists for uevent processing (bnc#478874)
- Set stacksize of uevent handling thread (bnc#478874)
- Increase uevent buffer size
- Strip trailing blanks from wwid
- Stack overflow in uev_trigger (bnc#476540)
* Thu Feb 26 2009 hare@suse.de
- Fixup multibus zero path handling (bnc#476330)
- Update checker handling for blocked devices
- Only pass block events to multipathd
- Clean up uevent processing (bnc#478874)
- Set stacksize correctly for event processing thread (bnc#478874)
* Mon Feb 23 2009 hare@suse.de
- Remove stray umask() call (bnc#458598)
- Don't call kpartx if no paths are active (bnc#473352)
* Thu Feb 19 2009 hare@suse.de
- Multipathd dies immediately after startup (bnc#473029)
- Return ghost state if port is in standby (bnc#475816)
- Switch off queue_if_no_path before removing paths (bnc#475523)
* Mon Feb  9 2009 hare@suse.de
- Fix leastpending loadbalancer output (bnc#444199)
- Start waitevent checker on new paths (bnc#473841)
- Use 'noflush' for kpartx (bnc#473352)
* Fri Feb  6 2009 hare@suse.de
- Display multipath output for leastpending loadbalancer
  properly (bnc#444199)
* Wed Feb  4 2009 hare@suse.de
- Set queue_if_no_path setting during map reload (bnc#472253)
- Remove obsolete 'umount map' uevent handling
- Retry TUR on driver errors (bnc#456961)
* Tue Feb  3 2009 hare@suse.de
- Copy persistent bindings file into initramfs (bnc#468804)
- Invert DM_STATE check for kpartx rules (bnc#440959)
* Mon Feb  2 2009 hare@suse.de
- Correct dbg_malloc() definition
- Fix more memory leaks
- Double free on path release (bnc#458393)
* Mon Jan 26 2009 hare@suse.de
- Don't access blocked devices in checkerloop()
- Check for validity in VECTOR_XXX defines (bnc#469269,bnc#457465)
* Fri Jan 23 2009 hare@suse.de
- Update dev_loss_tmo handling (bnc#458393)
- Fix directio error messages
- Update sdev_state handling
* Mon Jan 19 2009 hare@suse.de
- Add new HP machines to hardware table (bnc#442133)
- Print device-mapper tables for debugging
- Properly quote variables in mkinitrd scripts (bnc#447966)
- shuffle call to memarea_init
- Add xdr_setsite in init scripts (bnc#459529)
* Tue Jan 13 2009 hare@suse.de
- Do not run checkers or prioritizers on blocked devices
  (bnc#464155)
- Implement dev_loss_tmo and fast_io_fail_tmo (bnc#464155)
- Use default values for dev_loss_tmo and fast_io_fail_tmo
- Display checker and prio name on failure
- Add more debugging output
* Mon Jan 12 2009 hare@suse.de
- Set max_fds setting for multipath (bnc#457443)
- Enhance error messages for checker and prio loading (bnc#456214)
- Fix merge errors for prio_weightedpath (bnc#441007)
- Fix sysfs_attr_get_value (bnc#456747)
- Do not reinitialize prio and checker lists after config file
  has been parsed (bnc#464373)
- Minor cleanups
* Thu Dec  4 2008 hare@suse.de
- Split off IBM ESS hwtable entries (bnc#439763)
- Reload map when device R/O setting changes (bnc#440959)
* Fri Nov 21 2008 hare@suse.de
- Add 'Weighted Paths' prioritizer (bnc#441007)
- Fix crashes in update_multipath
* Thu Nov 20 2008 hare@suse.de
- Valgrind fixes
  * Add missing initialisation
  * Always allocate memory for alias
  * Check return value of basename
- Adapt to new sysfs layout (bnc#435215, bnc#445041)
- Use /sys/dev to speedup reverse lookups
- Rework sysfs device handling (bnc#435215, bnc#438031)
- Search for correct hardware entry during reconfigure (bnc#435688)
- Use local variables for device mapper params
- Allow zero paths for multipath maps
* Mon Nov 17 2008 hare@suse.de
- Update HP hardware table (bnc#442133)
- Zero out lines in print.c (bnc#445023)
* Mon Nov 10 2008 hare@suse.de
- Check for empty mpvecs in mpvec_garbage_collector() (bnc#437245)
- dmraid uuid starts with 'DMRAID' (bnc#439439)
- Handle arguments to multipathd from the init file
* Thu Nov  6 2008 ro@suse.de
- commenting multiline rpm macros is dangerous (read broken)
  remove percent sign in commented macro lines
* Mon Nov  3 2008 hare@suse.de
- Use pthread_join() during shutdown to avoid crash (bnc#437245)
- Fixup '%%n' to handle '!' kernel device name syntax (bnc#435172)
- Use correct commandline for cciss scsi_id callouts (bnc#435172)
- Do not check for valid mp context in get_state() (bnc#433659)
- Link directio checker against libaio (bnc#433659)
- Use regmatch when checking for duplicates in hwtable (bnc#439763)
* Mon Oct 27 2008 hare@suse.de
- Patches from mainline:
  * Increase bindings file lock timeout
  * Fixes for 'show paths format'
  * Add 'show wildcards' cli cmd
  * Add support for IBM storage devices
- fopen() returns NULL on failure (bnc#432598)
- Read verbosity level from configuration file (bnc#388284)
- kpartx -l does not remove it's loop device (bnc#417266)
- Missing fixes for libprio ontap.c (bnc#426975)
- Increase buffer size in find_loop_by_file (bnc#436428)
- Include SCSI device handler modules for initrd (bnc#431877)
* Fri Sep 26 2008 hare@suse.de
- Implement map resize (FATE#302007)
- Handle cciss devices correctly (bnc#419123)
* Wed Sep 24 2008 ro@suse.de
- use udevadm info instead of udevinfo
* Wed Sep  3 2008 hare@suse.de
- Merge in fixes from upstream:
  * Add IBM IPR to hardware table (bnc#419086)
  * Add IBM DS4300 to hardware table
  * Fix settings for scsi_id changes
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Thu Aug 28 2008 ro@suse.de
- fix init scripts
* Wed Jul 23 2008 hare@suse.de
- Update to version 0.4.8
- Include changes from SLES10
- Include mkinitrd scriptlets
* Wed May 28 2008 hare@suse.de
- Calculate correct partition offset in kpartx (bnc#394658)
* Fri May  9 2008 hare@suse.de
- Fixup kpartx rules (bnc#387667)
* Tue Apr 29 2008 hare@suse.de
- Merge in fixes from upstream
- Merge fixes from SLES10 SP2
* Wed Sep 19 2007 hare@suse.de
- Fixup generated dm_linear udev rules (#218122)
* Thu Aug 30 2007 hare@suse.de
- Rework dm_linear; udev rules should only be
  created if the feature was activated (#302422)
* Fri Aug 10 2007 hare@suse.de
- Implement dm_linear (#218122)
* Thu Aug  2 2007 hare@suse.de
- Merge in latest fixes from upstream
- Remove local patches; merge with upstream
- Fix kpartx handling of extended partitions
- Use underscores for partition names (#293792)
* Mon May 21 2007 hare@suse.de
- Rework udev handling
- Split off kpartx package
* Mon May 14 2007 hare@suse.de
- Merge in latest fixes from upstream
- Add all SuSE specific files to git repository.
* Fri May 11 2007 hare@suse.de
- Include latest changes from upstream
- Remove libsysfs (242766)
- Handle extended partitions for kpartx
* Mon Dec  4 2006 dmueller@suse.de
- don't build as root
* Fri Nov 17 2006 hare@suse.de
- integrate upstream fixes
- update udev rule for YaST2 dmraid support (217807])
* Mon Nov  6 2006 hare@suse.de
- Really fixup udev rule (216167).
* Fri Oct 20 2006 ro@suse.de
- make it build
* Mon Sep 25 2006 hare@suse.de
- update to latest fixes from git tree
- remove fixes integrated in upstream
- fixup udev rule (#203688)
* Wed Sep 13 2006 ro@suse.de
- use device-mapper-devel in BuildRequires
* Thu Aug 31 2006 hare@suse.de
- include latest fixes from git tree
- update kpartx_id and udev rules to work
  with dmraid.
- Fix return value for multipath -l
* Thu Aug 17 2006 ro@suse.de
- workaround problem in git-patch
  normal patch can't do a "rename", so copy file first
* Tue Jul 11 2006 hare@suse.de
- Update to official version 0.4.7
- Refactor git update to apply to 0.4.7
* Wed Jun 28 2006 hare@suse.de
- Remove blacklisting of dasd device node,
  use product_blacklist instead (#188688)
* Mon Jun 12 2006 hare@suse.de
- Add 72-multipath-compat.rules to create 'by-name'
  symlink again for compability (#183663)
* Fri Jun  2 2006 hare@suse.de
- Merge in fixed from upstream
  - Set device-mapper name correctly (#181127)
* Thu Jun  1 2006 hare@suse.de
- Merge in fixes from upstream
  - Fixup aliasing handling
  - Fix string length in pp_alua
- Use correct regexp patterns for hwtable (#177842)
- Fixup 71-multipath.rules to work correctly with the
  updated device-mapper online/offline events (#176516 - LTC23961)
- Add kpartx_id for the updated 71-multipath.rules
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Tue May  2 2006 hare@suse.de
- Merge in fixes from upstream
  - Merged local patches
  - Added hds_modular prioritizer
- Remove merged patches
- Allow for setting of maximum number of open files (#149979)
- Implement 'stop' for init scripts
* Mon Apr 10 2006 hare@suse.de
- Lowering priority for pp_tpc
- Split off DS6000 to fixup priority handler (#161347)
* Wed Apr  5 2006 hare@suse.de
- Disable debug messages in pp_tpc.
* Wed Mar 29 2006 hare@suse.de
- Explicitely create partitions at boot time (#159927)
* Thu Mar 23 2006 hare@suse.de
- Add hwtable entry for IBM 3526.
* Tue Mar 14 2006 hare@suse.de
- Fix another typo in mpath_id.
* Tue Mar 14 2006 hare@suse.de
- Fix typo in mpath_id.
* Mon Mar 13 2006 hare@suse.de
- Fix autobuild warnings.
- Include some minor fixed from upstream.
* Thu Mar  9 2006 hare@suse.de
- Add mpath_id program to call kpartx only on multipathed
  devices (#149995 - LTC21557).
- Include latest fixes from upstream.
* Wed Feb  8 2006 hare@suse.de
- Add device blacklisting (#85778)
- Further manpage installation fixes (#146179, #147053, #147911)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 hare@suse.de
- Fix manpage installation.
* Tue Jan 17 2006 hare@suse.de
- Include latest git fixes
- Remove old patches which are now upstream
- Add new hwtable entry for shark (#142176)
* Fri Dec 16 2005 hare@suse.de
- Fix dependencies for /etc/init.d/boot.multipath
- Fix kpartx rules to generate proper partition names.
* Wed Dec  7 2005 hare@suse.de
- Update to multipath-tools-0.4.6
- Include latest git fixes
- Port patches from SLES9 SP3
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Mon Sep  5 2005 matz@suse.de
- Fix broken usage of self-defined syscall [#114933].
* Fri Aug 26 2005 hare@suse.de
- Fix kpartx DASD partition support
* Thu Aug  4 2005 hare@suse.de
- Add 'directio' path checker
- Add support for S/390 DASD (PAV enablement).
- Update to package from SLES9
* Thu Jun 23 2005 lmb@suse.de
- LUs with a WWN containing "fd" were blacklisted (#93562).
* Thu Jun 16 2005 lmb@suse.de
- Remove stray newline character from /dev/disk/by-name/ entries
  (#85798, #86763)
- Clear /dev/disk/by-name/ on boot. (#85978)
- scsi_id now handles EMC Symmetrix; remove work-around for #86760.
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Mon Jun 13 2005 ro@suse.de
- neededforbuild: udev -> sysfsutils
* Tue Jun  7 2005 lmb@suse.de
- Import fixes from upstream.
- Hardware table updates for IBM ESS and EMC CX (#81688).
- Reinstate paths correctly after failure/restore cycle (#85781,
  [#86444]).
- Create map names again and fix segfault in devmap_name (#85798).
* Tue May 24 2005 hare@suse.de
- Fix segmentation fault with EMC Symmetrix (#85614).
- Update EMC Symmetrix entry in hwtable.
* Mon May 23 2005 hare@suse.de
- Add hwtable entry for IBM DS6000. (#63903)
- Do a rescan for devices if multipath command line option is set.
* Fri May 20 2005 hare@suse.de
- Fix devmap_name to use mapname and return proper status (#84748).
* Thu May 12 2005 lmb@suse.de
- Don't complain about default prio callout command (#81695).
- Reflect recent changes in boot.multipath as well as multipathd init
  scripts.
- Actually fail paths when they are detected to be failed by multipathd
  (#81679).
- killproc/startproc/checkproc can't be used with multipathd because of
  the way the daemon switches to its own namespace (#80443).
* Mon May  9 2005 hare@suse.de
- Use proper path checker for SGI TPC arrays.
- Update hwtable entries for SGI TP9400 and SGI TP9500.
- Write correct PID file (#80443).
* Mon Apr 25 2005 lmb@suse.de
- Update to 0.4.4: pp_alua now licensed as GPL (#78628).
- multipath-tools-oom-adj.patch: oom_adj to a valid value.
* Thu Apr 21 2005 lmb@suse.de
- Update to 0.4.4-pre18 which fixes the multipathd to initialize
  correctly in the absence of a configuration file (79239).
* Wed Apr 20 2005 lmb@suse.de
- Put multipath cache back into /dev because /var might not be mounted.
- Correct hwtable entry SGI TP9400, TP9500 and IBM 3542.
* Wed Apr 20 2005 lmb@suse.de
- Update to 0.4.4-pre16
- Build against device-mapper.1.01.xx correctly.
* Tue Apr 19 2005 lmb@suse.de
- Build w/o device-mapper update again.
* Mon Apr 18 2005 lmb@suse.de
- Update to 0.4.4-pre14
- Build versus device-mapper-1.01.01 to prevent deadlocks in
  kernel-space.
- Fix devmap_name to work with udev.
- Fix startup of multipathd w/o configuration file present.
* Fri Apr 15 2005 lmb@suse.de
- Add path priority checker for EMC CLARiiON and make necessary
  adjustments so that it gets called by default (#62491).
- Set the default udev dir to '/dev'
* Fri Apr 15 2005 hare@suse.de
- Fix to allocate default strings (#78056)
- Fix default entry for TPC9500.
* Wed Apr 13 2005 hare@suse.de
- Added pp_alua path priority checker.
- Update to multipath-tools-0.4.4-pre12.
* Mon Apr 11 2005 hare@suse.de
- Update to multipath-tools-0.4.4-pre10.
* Fri Apr  8 2005 hare@suse.de
- Update multipath to handle only true multipath devices (#62491).
- Update kpartx to use the device mapper target name if available.
- Add boot.multipath script for early set up of multipath targets.
* Thu Mar 31 2005 hare@suse.de
- Update devmap_name to select targets by table type (#62493).
* Tue Jan 25 2005 lmb@suse.de
- Update to 0.4.2 and fix some bugs + add support for the extended DM
  multipath kernel module. (#47491)
* Thu Nov 11 2004 hare@suse.de
- Fix bugs to make it work on S/390 (#47491).
* Fri Nov  5 2004 hare@suse.de
- Update to version 0.3.6 (#47491).
- Fix multipath init script
- Install configuration file example.
- Install multipathd in /sbin instead of /usr/bin.
* Tue Jul 20 2004 fehr@suse.de
- updated README mp-tools-issues.pdf (see #40640)
* Wed Jun  9 2004 fehr@suse.de
- added pdf with README to package (see #40640)
* Thu Jun  3 2004 fehr@suse.de
- updated to version 0.2.1
- removed patches zero-currpath.patch and rm-newline-in-name.patch
  already contained in 0.2.1
* Thu Jun  3 2004 fehr@suse.de
- added patch zero-currpath.patch (see bugzilla #40640)
* Wed May 26 2004 uli@suse.de
- fixed to build on s390x
* Wed May 26 2004 fehr@suse.de
- added patch rm-newline-in-name.patch (see bugzilla #40640)
* Tue May 25 2004 fehr@suse.de
- created initial version of a SuSE package from version 0.2.0 of
  multipath tools
